@@ -138,9 +138,9 @@
 #endif
 
 #if SIZEOF_UNSIGNED_CHAR == 1
- typedef unsigned char word8; 
+ typedef unsigned char byte; 
 #else
- typedef unsigned char word8;
+ typedef unsigned char byte;
 #endif
 
 
