@@ -18,7 +18,7 @@
 
 /* Some functions that didn't fit elsewhere */
 
-/* $Id: extra.c,v 1.20 2002/05/29 11:07:43 nmav Exp $ */
+/* $Id: extra.c,v 1.22 2002/06/09 19:02:14 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -44,7 +44,7 @@
 #endif
 
 static char rcsid[] =
-    "$Id: extra.c,v 1.20 2002/05/29 11:07:43 nmav Exp $";
+    "$Id: extra.c,v 1.22 2002/06/09 19:02:14 nmav Exp $";
 
 #ifndef NO_GETPASS
 	#define FREE_STR(x) \
@@ -649,12 +649,21 @@ unsigned char x;
 
 void print_enc_info(const char* infile, const char* outfile) {
 char tmperr[256];
+char* fmt;
 
    if (quiet == FALSE) {
       fprintf(stderr,
 	      _
 	      ("Algorithm: %s\nKeysize: %d\nMode: %s\nKeyword mode: %s\n"),
 	      algorithm, keysize, mode, keymode);
+      if (openpgp != FALSE)
+      	fmt = "openpgp";
+      else if (bare_flag==FALSE)
+        fmt = "mcrypt";
+      else fmt = "bare";
+      
+      fprintf(stderr, _("File format: %s\n"), fmt);
+
    }
    
    if ( stream_flag == FALSE) {
