@@ -16,7 +16,7 @@
  *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: keys.c,v 1.6 2002/05/26 18:20:30 nmav Exp $ */
+/* $Id: keys.c,v 1.7 2002/06/07 15:11:30 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -27,7 +27,7 @@
 #include <errors.h>
 #include <ufc_crypt.h>
 
-static char rcsid[] = "$Id: keys.c,v 1.6 2002/05/26 18:20:30 nmav Exp $";
+static char rcsid[] = "$Id: keys.c,v 1.7 2002/06/07 15:11:30 nmav Exp $";
 
 int _mcrypt_pgp_conv_keymode( const char* keymode, keygenid* km, hashid *halg) {
 	if (strcasecmp(keymode, "s2k-simple-md5")==0) {
@@ -63,7 +63,7 @@ int _mcrypt_pgp_conv_keymode( const char* keymode, keygenid* km, hashid *halg) {
 }
 
 int mcrypt_gen_key ( char* keymode, void* keyword, int keysize, 
-	void* salt, int saltsize, word8* password, int plen) {
+	void* salt, int saltsize, byte* password, int plen) {
 
 	KEYGEN data;
 	keygenid id=0;
