@@ -16,12 +16,12 @@
  *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: xmalloc.c,v 1.4 2001/09/08 10:26:39 nmav Exp $ */
+/* $Id: xmalloc.c,v 1.5 2002/05/25 17:01:40 nmav Exp $ */
 
 #include <defines.h>
 #include <extra.h>
 
-static char rcsid[] = "$Id: xmalloc.c,v 1.4 2001/09/08 10:26:39 nmav Exp $";
+static char rcsid[] = "$Id: xmalloc.c,v 1.5 2002/05/25 17:01:40 nmav Exp $";
 
 /* memory allocation */
 void *
@@ -139,3 +139,14 @@ void _secure_mcrypt_free( void* ptr, int size) {
 	free(ptr);
 }
 
+char* _mcrypt_strdup( const char* str) {
+char* ret;
+
+	ret = strdup( str);
+	if (ret==NULL) {
+		fprintf(stderr, _("Cannot allocate memory\n"));
+		exit(-1);
+	}
+	return ret;
+}
+
